@@ -126,6 +126,15 @@ class IMongoDataManager(persistent.interfaces.IPersistentDataManager):
     root = zope.interface.Attribute(
         """Get the root object, which is a mapping.""")
 
+    detect_conflicts = zope.interface.Attribute(
+        """A flag, when set it enables write conflict detection.""")
+
+    def get_collection(db_name, coll_name):
+        """Return the collection for the given DB and collection names."""
+
+    def get_collection_of_object(obj):
+        """Return the collection for an object."""
+
     def reset():
         """Reset the datamanager for the next transaction."""
 
@@ -138,6 +147,21 @@ class IMongoDataManager(persistent.interfaces.IPersistentDataManager):
         Note: The returned object is in the ghost state.
         """
 
+    def flush():
+        """Flush all changes to Mongo."""
+
+    def insert(obj):
+        """Insert an object into Mongo.
+
+        The correct collection is determined by object type.
+        """
+
+    def remove(obj):
+        """Remove an object from Mongo.
+
+        The correct collection is determined by object type.
+        """
+
 
 class IMongoConnectionPool(zope.interface.Interface):
     """MongoDB connection pool"""
@@ -172,4 +196,4 @@ class IMongoSpecProcessor(zope.interface.Interface):
     """An adapter to process find/update spec's"""
 
     def process(collection, spec):
-        """return the processed spec here"""
\ No newline at end of file
+        """return the processed spec here"""
