@@ -16,7 +16,6 @@ import UserDict
 import pymongo
 
 from mongopersist import interfaces
-from mongopersist.datamanager import processSpec
 
 class MongoCollectionMapping(UserDict.DictMixin, object):
     __mongo_database__ = None
@@ -31,13 +30,13 @@ class MongoCollectionMapping(UserDict.DictMixin, object):
 
     def get_mongo_collection(self):
         db_name = self.__mongo_database__ or self._m_jar.default_database
-        return self._m_jar._conn[db_name][self.__mongo_collection__]
+        return self._m_jar.get_collection(db_name, self.__mongo_collection__)
 
     def __getitem__(self, key):
         filter = self.__mongo_filter__()
         filter[self.__mongo_mapping_key__] = key
         coll = self.get_mongo_collection()
-        doc = coll.find_one(processSpec(coll, filter))
+        doc = coll.find_one(filter)
         if doc is None:
             raise KeyError(key)
         db_name = self.__mongo_database__ or self._m_jar.default_database
@@ -64,4 +63,4 @@ class MongoCollectionMapping(UserDict.DictMixin, object):
         coll = self.get_mongo_collection()
         return [
             doc[self.__mongo_mapping_key__]
-            for doc in coll.find(processSpec(coll, filter))]
+            for doc in coll.find(filter)]
