@@ -212,7 +212,7 @@ class ObjectWriter(object):
 
     def store(self, obj, ref_only=False):
         db_name, coll_name = self.get_collection_name(obj)
-        coll = self._jar._conn[db_name][coll_name]
+        coll = self._jar._get_collection(db_name, coll_name)
         if ref_only:
             # We only want to get OID quickly. Trying to reduce the full state
             # might cause infinite recusrion loop. (Example: 2 new objects
@@ -281,8 +281,9 @@ class ObjectReader(object):
                 raise ImportError(dbref)
             # Multiple object types are stored in the collection. We have to
             # look at the object to find out the type.
-            obj_doc = self._jar._conn[dbref.database][dbref.collection].find_one(
-                dbref.id, fields=('_py_persistent_type',))
+            obj_doc = self._jar\
+                ._get_collection(dbref.database, dbref.collection).find_one(
+                    dbref.id, fields=('_py_persistent_type',))
             if '_py_persistent_type' in obj_doc:
                 klass = self.simple_resolve(obj_doc['_py_persistent_type'])
             else:
@@ -292,7 +293,7 @@ class ObjectReader(object):
                         klass = self.simple_resolve(name_map_item['path'])
                         break
                 else:
-                    raise ImportError(path)
+                    raise ImportError(dbref)
             OID_CLASS_LRU[dbref.id] = klass
             return klass
 
@@ -372,19 +373,25 @@ class ObjectReader(object):
             return sub_obj
         return state
 
-    def set_ghost_state(self, obj):
+    def set_ghost_state(self, obj, doc=None):
         # Look up the object state by coll_name and oid.
-        coll = self._jar._conn[obj._p_oid.database][obj._p_oid.collection]
-        doc = coll.find_one({'_id': obj._p_oid.id})
+        if doc is None:
+            coll = self._jar._get_collection(
+                obj._p_oid.database, obj._p_oid.collection)
+            doc = coll.find_one({'_id': obj._p_oid.id})
+        # Remove unwanted attributes.
         doc.pop('_id')
         doc.pop('_py_persistent_type', None)
         # Store the serial, if conflict detection is enabled.
         if self._jar.detect_conflicts:
             obj._p_serial = p64(doc.pop('_py_serial', 0))
         # Now convert the document to a proper Python state dict.
-        state = self.get_object(doc, obj)
+        state = dict(self.get_object(doc, obj))
+        # Now store the original state. It is assumed that the state dict is
+        # not modified later.
+        self._jar._original_states[obj._p_oid] = doc
         # Set the state.
-        obj.__setstate__(dict(state))
+        obj.__setstate__(state)
 
     def get_ghost(self, dbref):
         # If we can, we return the object from cache.
