@@ -138,6 +138,11 @@ def doctest_SimpleMongoContainer_basic():
       >>> transaction.commit()
       >>> dm.root['c'].keys()
       []
+
+    The object is also removed from Mongo:
+
+      >>> pprint(list(db['person'].find()))
+      []
     """
 
 
@@ -192,7 +197,7 @@ def doctest_MongoContainer_basic():
       >>> dm.root['c']['stephan'].__parent__
       <mongopersist.zope.container.MongoContainer object at 0x7fec50f86500>
       >>> dm.root['c']['stephan'].__name__
-      'stephan'
+      u'stephan'
 
     We get a usual key error, if an object does not exist:
 
@@ -316,6 +321,44 @@ def doctest_MongoContainer_many_items():
       <Person Adam>
 """
 
+def doctest_MongoContainer_setitem_with_no_key():
+    """MongoContainer: __setitem__(None, obj)
+
+    Whenever an item is added with no key, the OID is used.
+
+      >>> transaction.commit()
+      >>> dm.root['people'] = container.MongoContainer('person')
+      >>> dm.root['people'][None] = Person(u'Stephan')
+
+    Let's now search and receive documents as result:
+
+      >>> sorted(dm.root['people'].keys())
+      [u'...']
+      >>> stephan = dm.root['people'].values()[0]
+      >>> stephan.__name__ == str(stephan._p_oid.id)
+      True
+"""
+
+def doctest_MongoContainer_add():
+    """MongoContainer: add(value, key=None)
+
+    Sometimes we just do not want to be responsible to determine the name of
+    the object to be added. This method makes this optional. The default
+    implementation assigns the OID as name:
+
+      >>> transaction.commit()
+      >>> dm.root['people'] = container.MongoContainer('person')
+      >>> dm.root['people'].add(Person(u'Stephan'))
+
+    Let's now search and receive documents as result:
+
+      >>> sorted(dm.root['people'].keys())
+      [u'...']
+      >>> stephan = dm.root['people'].values()[0]
+      >>> stephan.__name__ == str(stephan._p_oid.id)
+      True
+"""
+
 def doctest_MongoContainer_find():
     """MongoContainer: find
 
@@ -536,11 +579,11 @@ def doctest_MongoContainer_with_ZODB():
 
       >>> stephan = root['app']['people']['stephan']
       >>> stephan.__name__
-      'stephan'
+      u'stephan'
       >>> stephan.__parent__
       <mongopersist.zope.container.MongoContainer object at 0x7f6b6273b7d0>
 
-      >>> pprint(list(dm._conn[DBNAME]['person'].find()))
+      >>> pprint(list(dm._get_collection(DBNAME, 'person').find()))
       [{u'_id': ObjectId('4e7ed795e1382366a0000001'),
         u'key': u'stephan',
         u'name': u'Stephan',
